@@ -22,6 +22,8 @@ along with obdgpslogger.  If not, see <http://www.gnu.org/licenses/>.
 #ifndef __OBDCONFIGFILE_H
 #define __OBDCONFIGFILE_H
 
+#include "obdservicecommands.h"
+
 #ifdef __cplusplus
 extern "C" {
 #endif //  __cplusplus
@@ -32,14 +34,32 @@ struct OBDGPSConfig {
 	const char *gps_device; //< Full path to the gps device
 	int samplerate; //< SampleRate [number-per-second]
 	int optimisations; //< Enable Optimsations
+	const char *log_columns; //< Columns to log [comma-separated]
+	long baudrate; //< Baudrate
+	const char *log_file; //< Log to this file
 };
 
 /// Load a config, return a struct. Must be free'd using freeOBDGPSConfig
-struct OBDGPSConfig *obd_loadConfig();
+struct OBDGPSConfig *obd_loadConfig(int verbose);
 
 /// Free a config created by loadOBDGPSConfig
 void obd_freeConfig(struct OBDGPSConfig *c);
 
+/// Write the passed config struct to the config file
+/** \return 0 on success, non-zero on failure */
+int obd_writeConfig(struct OBDGPSConfig *c);
+
+/// Get a list of obdservicecommands.
+/** My god. It's full of stars
+ \param log_columns comma-separated list of columns
+ \param cmds when returned, this will point to a list of obdservicecmds, terminated with a NULL
+ \return number of commands populated [not counting NULL sentinel] or -1 on error
+ */
+int obd_configCmds(const char *log_columns, struct obdservicecmd ***cmds);
+
+/// Free a list of service commands allocated by obd_configCmds
+void obd_freeConfigCmds(struct obdservicecmd **cmds);
+
 #ifdef __cplusplus
 }
 #endif //  __cplusplus
